@@ -23,10 +23,7 @@ import Cogl from "gi://Cogl";
 import Meta from "gi://Meta";
 import Clutter from "gi://Clutter";
 
-import {
-    Extension,
-    gettext as _,
-} from "resource:///org/gnome/shell/extensions/extension.js";
+import { Extension, gettext as _ } from "resource:///org/gnome/shell/extensions/extension.js";
 
 import * as Main from "resource:///org/gnome/shell/ui/main.js";
 
@@ -50,9 +47,7 @@ export default class Shortcuts extends Extension {
         ];
 
         settingsToConnect.forEach(({ key, method }) => {
-            this._settingSignals.push(
-                this._settings.connect(`changed::${key}`, method.bind(this))
-            );
+            this._settingSignals.push(this._settings.connect(`changed::${key}`, method.bind(this)));
         });
         this._isAdded = false;
         // eslint-disable-next-line no-unused-vars
@@ -104,43 +99,43 @@ export default class Shortcuts extends Extension {
                 this._columns = this._settings.get_int("maxcolumns");
                 this._stage = new St.BoxLayout({
                     style_class: "background-boxlayout",
-                    vertical: true,
+                    orientation: Clutter.Orientation.VERTICAL,
                 });
                 this._main_panel = new St.BoxLayout({
                     style_class: "panel-boxlayout",
-                    vertical: false,
+                    orientation: Clutter.Orientation.HORIZONTAL,
                 });
 
                 this._stage.add_child(this._main_panel);
 
                 this._child1_panel = new St.BoxLayout({
                     style_class: "child-boxlayout",
-                    vertical: true,
+                    orientation: Clutter.Orientation.VERTICAL,
                 });
                 this._child2_panel = new St.BoxLayout({
                     style_class: "child-boxlayout",
-                    vertical: true,
+                    orientation: Clutter.Orientation.VERTICAL,
                 });
                 this._main_panel.add_child(this._child1_panel);
                 this._main_panel.add_child(this._child2_panel);
                 if (this._columns >= 3) {
                     this._child3_panel = new St.BoxLayout({
                         style_class: "child-boxlayout",
-                        vertical: true,
+                        orientation: Clutter.Orientation.VERTICAL,
                     });
                     this._main_panel.add_child(this._child3_panel);
                 }
                 if (this._columns >= 4) {
                     this._child4_panel = new St.BoxLayout({
                         style_class: "child-boxlayout",
-                        vertical: true,
+                        orientation: Clutter.Orientation.VERTICAL,
                     });
                     this._main_panel.add_child(this._child4_panel);
                 }
                 if (this._columns === 5) {
                     this._child5_panel = new St.BoxLayout({
                         style_class: "child-boxlayout",
-                        vertical: true,
+                        orientation: Clutter.Orientation.VERTICAL,
                     });
                     this._main_panel.add_child(this._child4_panel);
                 }
@@ -149,9 +144,7 @@ export default class Shortcuts extends Extension {
                 this._stage.add_child(
                     new St.Label({
                         style_class: "superkey-prompt",
-                        text: _(
-                            "The super key is the Windows key on most keyboards"
-                        ),
+                        text: _("The super key is the Windows key on most keyboards"),
                     })
                 );
 
@@ -170,10 +163,8 @@ export default class Shortcuts extends Extension {
             let monitor = Main.layoutManager.primaryMonitor;
 
             this._stage.set_position(
-                monitor.x +
-                    Math.floor(monitor.width / 2 - this._stage.width / 2),
-                monitor.y +
-                    Math.floor(monitor.height / 2 - this._stage.height / 2)
+                monitor.x + Math.floor(monitor.width / 2 - this._stage.width / 2),
+                monitor.y + Math.floor(monitor.height / 2 - this._stage.height / 2)
             );
             this._visible = true;
         } else {
@@ -182,74 +173,95 @@ export default class Shortcuts extends Extension {
         }
     }
 
+    /**
+     * gets the panel to which the next shortcut should be added based on the list progress value (2 columns).
+     *
+     * @param {*} listProgress list progress value between 0 and 1
+     * @returns {*} panel to which the next shortcut should be added 1 or 2 columns
+     */
     _getPanel2columns(listProgress) {
         return listProgress < 0.5 ? this._child1_panel : this._child2_panel;
     }
-
+    /**
+     * gets the panel to which the next shortcut should be added based on the list progress value (3 columns).
+     *
+     * @param {*} listProgress list progress value between 0 and 1
+     * @returns {*} panel to which the next shortcut should be added 1,2 or 3 columns
+     */
     _getPanel3columns(listProgress) {
-        if (listProgress < 0.33) {
-            return this._child1_panel;
-        } else if (listProgress < 0.66) {
-            return this._child2_panel;
-        } else {
-            return this._child3_panel;
-        }
+        const panels = [this._child1_panel, this._child2_panel, this._child3_panel];
+        const index = Math.min(Math.floor(listProgress * 3), 2);
+        return panels[index];
     }
-
+    /**
+     * gets the panel to which the next shortcut should be added based on the list progress value (4 columns).
+     *
+     * @param {*} listProgress list progress value between 0 and 1
+     * @returns {*} panel to which the next shortcut should be added 1,2,3 or 4 columns
+     */
     _getPanel4columns(listProgress) {
-        if (listProgress < 0.25) {
-            return this._child1_panel;
-        } else if (listProgress < 0.5) {
-            return this._child2_panel;
-        } else if (listProgress < 0.75) {
-            return this._child3_panel;
-        } else {
-            return this._child4_panel;
-        }
+        const panels = [this._child1_panel, this._child2_panel, this._child3_panel, this._child4_panel];
+        const index = Math.min(Math.floor(listProgress * 4), 3);
+        return panels[index];
     }
-
+    /**
+     * gets the panel to which the next shortcut should be added based on the list progress value (5 columns).
+     *
+     * @param {*} listProgress list progress value between 0 and 1
+     * @returns {*} panel to which the next shortcut should be added 1,2,3,4 or 5 columns
+     */
     _getPanel5columns(listProgress) {
-        if (listProgress < 0.2) {
-            return this._child1_panel;
-        } else if (listProgress < 0.4) {
-            return this._child2_panel;
-        } else if (listProgress < 0.6) {
-            return this._child3_panel;
-        } else if (listProgress < 0.8) {
-            return this._child4_panel;
-        } else {
-            return this._child5_panel;
+        const panels = [
+            this._child1_panel,
+            this._child2_panel,
+            this._child3_panel,
+            this._child4_panel,
+            this._child5_panel,
+        ];
+        const index = Math.min(Math.floor(listProgress * 5), 4);
+        return panels[index];
+    }
+
+    /**
+     * gets the panel to which the next shortcut should be added based on the list progress value.
+     *
+     * @param {*} listProgress list progress value between 0 and 1
+     * @returns {*} panel to which the next shortcut should be added
+     */
+    _getPanel(listProgress) {
+        switch (this._columns) {
+            case 2:
+                return this._getPanel2columns(listProgress);
+            case 3:
+                return this._getPanel3columns(listProgress);
+            case 4:
+                return this._getPanel4columns(listProgress);
+            case 5:
+                return this._getPanel5columns(listProgress);
+            default:
+                Main.notifyError(_("Invalid number of columns"));
+                this.getLogger().error(_("Invalid number of columns"));
+                return null;
         }
     }
 
-    _getPanel(listProgress) {
-        if (this._columns === 2) {
-            return this._getPanel2columns(listProgress);
-        } else if (this._columns === 3) {
-            return this._getPanel3columns(listProgress);
-        } else if (this._columns === 4) {
-            return this._getPanel4columns(listProgress);
-        } else if (this._columns === 5) {
-            return this._getPanel5columns(listProgress);
-        } else {
-            Main.notifyError(_("Invalid number of columns"));
-            return null;
-        }
-    }
+    /**
+     * Description placeholder
+     *
+     * @param {*} APP_ID application ID for which to get the shortcuts file
+     * @returns {string} path to the app-specific shortcuts file
+     */
     _getAppIDjson(APP_ID) {
-        let systempath = "/etc/" + this.uuid + "/" + APP_ID;
-        let userpath =
-            GLib.get_user_config_dir() + "/" + this.uuid + "/" + APP_ID;
+        const systempath = "/etc/" + this.uuid + "/" + APP_ID;
+        const userpath = GLib.get_user_config_dir() + "/" + this.uuid + "/" + APP_ID;
         if (GLib.file_test(userpath, GLib.FileTest.EXISTS)) {
             return userpath;
         }
         if (GLib.file_test(systempath, GLib.FileTest.EXISTS)) {
             return systempath;
         }
-        let msg = _(
-            "Application spedific Shortcuts file not found: '%s'"
-        ).format(APP_ID);
-        console.log(msg);
+        let msg = _("Application spedific Shortcuts file not found: '%s'").format(APP_ID);
+        this.getLogger().log(msg);
         return "";
     }
     /**
@@ -273,10 +285,9 @@ export default class Shortcuts extends Extension {
             }
         }
         if (!GLib.file_test(SHORTCUTS_FILE, GLib.FileTest.EXISTS)) {
-            let msg = _("Shortcuts file not found: '%s'").format(
-                SHORTCUTS_FILE
-            );
+            let msg = _("Shortcuts file not found: '%s'").format(SHORTCUTS_FILE);
             Main.notifyError(msg);
+            this.getLogger().error(msg);
             return;
         }
         let file = Gio.file_new_for_path(SHORTCUTS_FILE);
@@ -284,6 +295,7 @@ export default class Shortcuts extends Extension {
         if (!result) {
             let msg = _("Unable to read file: '%s'").format(SHORTCUTS_FILE);
             Main.notifyError(msg);
+            this.getLogger().error(msg);
             return;
         }
 
@@ -306,7 +318,7 @@ export default class Shortcuts extends Extension {
             for (const j_element of i_element.shortcuts) {
                 let item_panel = new St.BoxLayout({
                     style_class: "item-boxlayout",
-                    vertical: false,
+                    orientation: Clutter.Orientation.HORIZONTAL,
                 });
                 let key = _(j_element.key);
                 let description = _(j_element.description);
@@ -382,15 +394,16 @@ export default class Shortcuts extends Extension {
             });
 
             this._button.set_child(icon);
-            this._button.connect(
-                "button-press-event",
-                this._onButtonPress.bind(this)
-            );
+            this._button.connect("button-press-event", this._onButtonPress.bind(this));
 
             Main.panel._rightBox.insert_child_at_index(this._button, 0);
             this._isAdded = true;
         }
     }
+
+    /**
+     * handles the button press events on the icon in the top panel.
+     */
     _onButtonPress(actor, event) {
         let button = event.get_button();
         if (button === 1 || button === 3) {
@@ -408,13 +421,12 @@ export default class Shortcuts extends Extension {
      */
     _setShortcutsFile() {
         if (!this._settings.get_boolean("use-custom-shortcuts")) {
-            this._settings.set_string(
-                "shortcuts-file",
-                this.dir.get_child("shortcuts.json").get_path()
-            );
+            this._settings.set_string("shortcuts-file", this.dir.get_child("shortcuts.json").get_path());
         }
     }
-
+    /**
+     * Sets the transparency of the shortcuts pop-up based on the settings
+     */
     _setTransparency() {
         if (this._settings.get_boolean("use-transparency")) {
             this._visibility = this._settings.get_int("visibility") / 100;
@@ -422,17 +434,18 @@ export default class Shortcuts extends Extension {
             this._visibility = 1;
         }
     }
-
+    /**
+     * Sets whether the extension should use app-specific shortcuts files
+     * and creates the directory for them if it does.
+     */
     _setEnableAppspecific() {
-        this._appspecific = this._settings.get_boolean(
-            "enable-appspecific-files"
-        );
+        this._appspecific = this._settings.get_boolean("enable-appspecific-files");
         if (this._appspecific) {
             const path = GLib.get_user_config_dir() + "/" + this.uuid;
             const exitCode = GLib.mkdir_with_parents(path, 493);
             if (exitCode === -1) {
                 let msg = _("Failed to create directory: '%s'").format(path);
-                console.log(msg);
+                this.getLogger().log(msg);
             }
         }
     }
